Spanned

Struct Spanned 

pub struct Spanned<T> {
    pub value: T,
    pub span: (usize, usize),
}
A wrapper around a value that also contains the span of the value in the source.

Fields

value: T

The underlying parsed node.

span: (usize, usize)

The span of the node in the source. The first value is the inclusive start of the span, and the second value is the exclusive end of the span.